##  Find Information from Fact Sheets
[Fact Sheets](https://help.sap.com/docs/leanix/ea/fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD "Fact sheets in SAP LeanIX are used to record essential and comprehensive details about each architectural object, such as applications, business capabilities, IT components, etc. Learn about their structure, types, and subtypes.") are used to document and save information regarding architectural objects, like Applications, Business Capabilities, Projects, IT Components, etc. SAP LeanIX can serve as your single source of truth for any information related to your organization's IT landscape. Let's look at a couple of common scenarios to get a better understanding of how it can be useful for you.
For instance, you may want to check which applications support specific business capabilities in a particular region or business unit. To find that information from fact sheets, do the following:
  1. Navigate to the Inventory tab in your workspace.
  2. Make use of the [Search and Filter functions](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory?locale=en-US&state=PRODUCTION&version=CLOUD "Searching and filtering in the inventory helps efficiently manage your data. Learn how to quickly find fact sheets, apply filters, manage filters, and save search results for future access.") in the Inventory.
    1. Select Application from the Filter panel on the left to apply a filter that displays only the Application Fact Sheets.
    2. Select the Business capabilities, regions, and business units to narrow down to your requirements.


You now have a list of all applications that support a particular business capability in a particular business unit.
![Finding Fact Sheets](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e4afd7a4410149e72d75c9ffc8f56_LowRes.gif)
Finding Fact Sheets
Maybe you are seeking details about a particular application and want to contact the responsible person to get access or a license. To find information in the Fact sheet, do the following:
  1. Access a specific Fact Sheet by searching for it in the search bar at the top. You can also scroll through the list of Application Fact Sheets in the Inventory.
  2. Click on the Fact Sheet to open it for detailed viewing.
  3. Browse through different tabs of the Fact Sheet to view relevant details about the application.


To learn more about Fact Sheets, see [Fact Sheets](https://help.sap.com/docs/leanix/ea/fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD "Fact sheets in SAP LeanIX are used to record essential and comprehensive details about each architectural object, such as applications, business capabilities, IT components, etc. Learn about their structure, types, and subtypes.").
Another scenario could be that you might be overseeing a portfolio of Applications or Business, with responsibilities extending to multiple Fact Sheets. You can access all your subscribed Fact Sheets in one place by filtering for subscribed Fact Sheets:
![Filter by subscription](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274749807a441014807adf4a28322d1f_LowRes.png)
Filter by subscription
